# PEP-484 Stubs for django-filter ::: Beta

[![Build Status](https://travis-ci.org/DavisRayM/django-filter-stubs.svg?branch=master)](https://travis-ci.org/DavisRayM/django-filter-stubs)
[![Checked with mypy](http://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)

This package contains type subs to provide more precise static types for Django Filters.

## Installation

```bash
pip install django-filter-stubs
```
